import Adapter from '@ember-data/adapter';
import DS from 'ember-data';
import RSVP from 'rsvp';
import Store from '@ember-data/store';
import { CollectionReference, Firestore, Query, WriteBatch } from 'firebase/firestore';
interface ModelClass {
    modelName: string;
}
interface AdapterOption {
    isRealtime?: boolean;
    queryId?: string;
    buildReference?(db: Firestore): CollectionReference;
    filter?(db: CollectionReference): Query;
    include?(batch: WriteBatch, db: Firestore): void;
    [key: string]: unknown;
}
interface Snapshot extends DS.Snapshot {
    adapterOptions: AdapterOption;
}
interface SnapshotRecordArray extends DS.SnapshotRecordArray<string | number> {
    adapterOptions: AdapterOption;
}
interface BelongsToRelationshipMeta {
    type: string;
    options: {
        isRealtime?: boolean;
    };
}
interface HasManyRelationshipMeta {
    key: string;
    type: string;
    options: {
        isRealtime?: boolean;
        buildReference?(db: Firestore, record: unknown): CollectionReference;
        filter?(db: CollectionReference | Query, record: unknown): Query;
    };
}
export default class CloudFirestoreModularAdapter extends Adapter {
    private firestoreDataManager;
    protected referenceKeyName: string;
    private get isFastBoot();
    generateIdForRecord(_store: Store, type: string): string;
    createRecord(store: Store, type: ModelClass, snapshot: Snapshot): RSVP.Promise<unknown>;
    updateRecord(_store: Store, type: ModelClass, snapshot: Snapshot): RSVP.Promise<unknown>;
    deleteRecord(_store: Store, type: ModelClass, snapshot: Snapshot): RSVP.Promise<unknown>;
    findRecord(_store: Store, type: ModelClass, id: string, snapshot: Snapshot): RSVP.Promise<unknown>;
    findAll(_store: Store, type: ModelClass, _sinceToken: string, snapshotRecordArray?: SnapshotRecordArray): RSVP.Promise<unknown>;
    query(_store: Store, type: ModelClass, queryOption: AdapterOption, recordArray: DS.AdapterPopulatedRecordArray<unknown>): RSVP.Promise<unknown>;
    findBelongsTo(_store: Store, _snapshot: Snapshot, url: string, relationship: BelongsToRelationshipMeta): RSVP.Promise<unknown>;
    findHasMany(store: Store, snapshot: Snapshot, url: string, relationship: HasManyRelationshipMeta): RSVP.Promise<unknown>;
    private buildCollectionRef;
    private addDocRefToWriteBatch;
    private addIncludeToWriteBatch;
    private buildWriteBatch;
    private buildHasManyCollectionRef;
}
declare module 'ember-data/types/registries/adapter' {
    export default interface AdapterRegistry {
        'cloud-firestore-modular': CloudFirestoreModularAdapter;
    }
}
export {};
